@@ -46,6 +46,7 @@ mkdir -p $DC_INSTALL_DIR
 mkdir -p $DC_INSTALL_DIR/plugins
 # WCX plugins directories
 mkdir -p $DC_INSTALL_DIR/plugins/wcx
+mkdir -p $DC_INSTALL_DIR/plugins/wcx/base64
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/cpio
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/deb
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/rpm
@@ -72,12 +73,14 @@ mkdir -p $DC_INSTALL_DIR/plugins/dsx/dsxlocate
 cp -a doublecmd                    $DC_INSTALL_DIR/
 cp -a doublecmd.help               $DC_INSTALL_DIR/
 cp -a doublecmd.zdli               $DC_INSTALL_DIR/
-cp -a pixmaps.txt                  $DC_INSTALL_DIR/
-cp -a multiarc.ini                 $DC_INSTALL_DIR/
 cp -a pinyin.tbl                   $DC_INSTALL_DIR/
 
+# Copy default settings
+cp -r default                      $DC_INSTALL_DIR/
+
 # copy plugins
 # WCX
+install -m 644 plugins/wcx/base64/base64.wcx        $DC_INSTALL_DIR/plugins/wcx/base64/
 install -m 644 plugins/wcx/cpio/cpio.wcx            $DC_INSTALL_DIR/plugins/wcx/cpio/
 install -m 644 plugins/wcx/deb/deb.wcx              $DC_INSTALL_DIR/plugins/wcx/deb/
 install -m 644 plugins/wcx/rpm/rpm.wcx              $DC_INSTALL_DIR/plugins/wcx/rpm/
@@ -143,7 +146,8 @@ if [ -z $CK_PORTABLE ]
     install -m 644 install/linux/org.doublecmd.root.policy $DC_INSTALL_PREFIX/usr/share/polkit-1/actions/
   else
     # Make portable version
-    touch $DC_INSTALL_DIR/doublecmd.inf
+    mkdir $DC_INSTALL_DIR/settings
+    touch $DC_INSTALL_DIR/settings/doublecmd.inf
     # Copy documentation
     mkdir -p $DC_INSTALL_DIR/doc
     cp -a doc/*.txt $DC_INSTALL_DIR/doc/
